@@ -1,15 +1,15 @@
 from __future__ import annotations
 
-import calendar
 import datetime
 import time
 from abc import ABC, abstractmethod
-from typing import Any, cast
+from typing import cast
 
 from deprecated.sphinx import versionadded, versionchanged
 
 from limits.typing import (
     Dict,
+    List,
     MongoClient,
     MongoCollection,
     MongoDatabase,
@@ -122,19 +122,17 @@ class MongoDBStorageBase(Storage, MovingWindowSupport, ABC):
         self.counters.find_one_and_delete({"_id": key})
         self.windows.find_one_and_delete({"_id": key})
 
-    def get_expiry(self, key: str) -> int:
+    def get_expiry(self, key: str) -> float:
         """
         :param key: the key to get the expiry for
         """
         counter = self.counters.find_one({"_id": key})
-        expiry = (
-            counter["expireAt"]
-            if counter
-            else datetime.datetime.now(datetime.timezone.utc)
+        return (
+            (counter["expireAt"] if counter else datetime.datetime.now())
+            .replace(tzinfo=datetime.timezone.utc)
+            .timestamp()
         )
 
-        return calendar.timegm(expiry.timetuple())
-
     def get(self, key: str) -> int:
         """
         :param key: the key to get the counter value for
@@ -205,7 +203,7 @@ class MongoDBStorageBase(Storage, MovingWindowSupport, ABC):
         except:  # noqa: E722
             return False
 
-    def get_moving_window(self, key: str, limit: int, expiry: int) -> Tuple[int, int]:
+    def get_moving_window(self, key: str, limit: int, expiry: int) -> Tuple[float, int]:
         """
         returns the starting point and the number of entries in the moving
         window
@@ -243,9 +241,9 @@ class MongoDBStorageBase(Storage, MovingWindowSupport, ABC):
         )
 
         if result:
-            return int(result[0]["min"]), result[0]["count"]
+            return result[0]["min"], result[0]["count"]
 
-        return int(timestamp), 0
+        return timestamp, 0
 
     def acquire_entry(self, key: str, limit: int, expiry: int, amount: int = 1) -> bool:
         """
@@ -259,23 +257,29 @@ class MongoDBStorageBase(Storage, MovingWindowSupport, ABC):
 
         timestamp = time.time()
         try:
-            updates: Dict[str, Any] = {  # type: ignore
-                "$push": {"entries": {"$each": [], "$position": 0, "$slice": limit}}
+            updates: Dict[
+                str,
+                Dict[str, Union[datetime.datetime, Dict[str, Union[List[float], int]]]],
+            ] = {
+                "$push": {
+                    "entries": {
+                        "$each": [timestamp] * amount,
+                        "$position": 0,
+                        "$slice": limit,
+                    }
+                },
+                "$set": {
+                    "expireAt": (
+                        datetime.datetime.now(datetime.timezone.utc)
+                        + datetime.timedelta(seconds=expiry)
+                    )
+                },
             }
 
-            updates["$set"] = {
-                "expireAt": (
-                    datetime.datetime.now(datetime.timezone.utc)
-                    + datetime.timedelta(seconds=expiry)
-                )
-            }
-            updates["$push"]["entries"]["$each"] = [timestamp] * amount
             self.windows.update_one(
                 {
                     "_id": key,
-                    "entries.%d" % (limit - amount): {
-                        "$not": {"$gte": timestamp - expiry}
-                    },
+                    f"entries.{limit - amount}": {"$not": {"$gte": timestamp - expiry}},
                 },
                 updates,
                 upsert=True,
